==> apertium-cat-srd_1.1.0.orig.tar.bz2: apertium-cat-srd-1.1.0/README.md <==
Catalan and Sardinian

                            apertium-cat-srd
===============================================================================

This is an Apertium language pair for translating between Catalan and
Sardinian. What you can use this language package for:

* Translating between Catalan and Sardinian
* Morphological analysis of Catalan and Sardinian
* Part-of-speech tagging of Catalan and Sardinian

For information on the latter two points, see subheading "For more
information" below

Requirements
===============================================================================

You will need the following software installed:

* lttoolbox (>= 3.3.0)
* apertium (>= 3.3.0)
* vislcg3 (>= 0.9.9.10297)
* apertium-cat
* apertium-srd

If this does not make any sense, we recommend you look at: www.apertium.org

Compiling
===============================================================================

Given the requirements being installed, you should be able to just run:

$ ./configure
$ make
# make install

You can use ./autogen.sh instead of ./configure you're compiling from
SVN. If you installed any prerequisite language packages using a --prefix
to ./configure, make sure to give the same --prefix to ./configure here.

Testing
===============================================================================

If you are in the source directory after running make, the following
commands should work:

$  echo "TODO test sentence 1" | apertium -d . cat-srd
TODO test translated sentence 1

$ echo "TODO test sentence 2" | apertium -d . srd-cat
TODO test translated sentence 2

After installing somewhere in $PATH, you should be able to do e.g.

$  echo "TODO test sentence 1" | apertium cat-srd
TODO test translated sentence 1

Files and data
===============================================================================

* apertium-cat-srd.cat-srd.dix  - Bilingual dictionary
* apertium-cat-srd.cat-srd.t1x  - Chunking rules for translating into Catalan
* apertium-cat-srd.srd-cat.t1x  - Chunking rules for translating into Sardinian
* apertium-cat-srd.cat-srd.t2x  - Interchunk rules for translating into Catalan
* apertium-cat-srd.srd-cat.t2x  - Interchunk rules for translating into Sardinian
* apertium-cat-srd.cat-srd.t3x  - Postchunk rules for translating into Catalan
* apertium-cat-srd.srd-cat.t3x  - Postchunk rules for translating into Sardinian
* apertium-cat-srd.cat-srd.lrx  - Lexical selection rules for translating into Catalan
* apertium-cat-srd.srd-cat.lrx  - Lexical selection rules for translating into Sardinian
* modes.xml                     - Translation modes

For more information
===============================================================================

* http://wiki.apertium.org/wiki/Installation
* http://wiki.apertium.org/wiki/apertium-cat-srd
* http://wiki.apertium.org/wiki/Using_an_lttoolbox_dictionary

Help and support
===============================================================================

If you need help using this language pair or data, you can contact:

* Mailing list: apertium-stuff@lists.sourceforge.net
* IRC: #apertium on irc.freenode.net

See also the file AUTHORS included in this distribution.

==> apertium-cat-srd_1.2.0.orig.tar.bz2: apertium-cat-srd-1.2.0/README.md <==
Catalan and Sardinian

                            apertium-cat-srd
===============================================================================

This is an Apertium language pair for translating between Catalan and
Sardinian. What you can use this language package for:

* Translating between Catalan and Sardinian
* Morphological analysis of Catalan and Sardinian
* Part-of-speech tagging of Catalan and Sardinian

For information on the latter two points, see subheading "For more
information" below

Requirements
===============================================================================

You will need the following software installed:

* lttoolbox (>= 3.3.0)
* apertium (>= 3.3.0)
* vislcg3 (>= 0.9.9.10297)
* apertium-cat
* apertium-srd

If this does not make any sense, we recommend you look at: apertium.org

Compiling
===============================================================================

Given the requirements being installed, you should be able to just run:

$ ./configure
$ make
# make install

You can use ./autogen.sh instead of ./configure you're compiling from
SVN. If you installed any prerequisite language packages using a --prefix
to ./configure, make sure to give the same --prefix to ./configure here.

Testing
===============================================================================

If you are in the source directory after running make, the following
commands should work:

$  echo "TODO test sentence 1" | apertium -d . cat-srd
TODO test translated sentence 1

$ echo "TODO test sentence 2" | apertium -d . srd-cat
TODO test translated sentence 2

After installing somewhere in $PATH, you should be able to do e.g.

$  echo "TODO test sentence 1" | apertium cat-srd
TODO test translated sentence 1

Files and data
===============================================================================

* apertium-cat-srd.cat-srd.dix  - Bilingual dictionary
* apertium-cat-srd.cat-srd.t1x  - Chunking rules for translating into Catalan
* apertium-cat-srd.srd-cat.t1x  - Chunking rules for translating into Sardinian
* apertium-cat-srd.cat-srd.t2x  - Interchunk rules for translating into Catalan
* apertium-cat-srd.srd-cat.t2x  - Interchunk rules for translating into Sardinian
* apertium-cat-srd.cat-srd.t3x  - Postchunk rules for translating into Catalan
* apertium-cat-srd.srd-cat.t3x  - Postchunk rules for translating into Sardinian
* apertium-cat-srd.cat-srd.lrx  - Lexical selection rules for translating into Catalan
* apertium-cat-srd.srd-cat.lrx  - Lexical selection rules for translating into Sardinian
* modes.xml                     - Translation modes

For more information
===============================================================================

* https://wiki.apertium.org/wiki/Installation
* https://wiki.apertium.org/wiki/apertium-cat-srd
* https://wiki.apertium.org/wiki/Using_an_lttoolbox_dictionary

Help and support
===============================================================================

If you need help using this language pair or data, you can contact:

* Mailing list: apertium-stuff@lists.sourceforge.net
* IRC: #apertium on irc.oftc.net

See also the file AUTHORS included in this distribution.
